@@ -16,9 +16,9 @@ class RoleType(Enum):
 
     def __init__(self, _id: int, team: Team):
         self._id = id
-        self._team: team
+        self._team = team
 
-    def get_team(self):
+    def get_team(self) -> Team:
         return self._team
 
 
@@ -83,18 +83,23 @@ class Role(Enum):
 
     @classmethod
     def from_index(cls, index):
-        return list(Role)[index]
+        return _roles_list[index]
 
-    def get_role_type(self):
+    def get_team(self) -> Team:
+        if self == Role.Random:
+            raise TypeError("Random does not have a team")
+        return self._role_type.get_team()
+
+    def get_role_type(self) -> RoleType:
         return self._role_type
 
-    def get_name(self, locale: Language = Language.English):
-        return self._name
+    def get_name(self, locale: Language = Language.English) -> str:
+        return self._name[locale]
     
     def get_english_name(self):
         return self.get_name(Language.English)
 
-    def get_original_author(self):
+    def get_original_author(self) -> Developer:
         return self._original_author
 
     def get_current_author(self):
@@ -102,3 +107,5 @@ class Role(Enum):
 
     def is_available(self):
         return self._available
+
+_roles_list = list(Role)
\ No newline at end of file
