@@ -2,7 +2,8 @@ import unittest
 
 from ks_constants.devs import Developer
 from ks_constants.maps import Map
-from ks_constants.roles import Role, RoleType
+from ks_constants.roles import Role, RoleType, Team
+from ks_constants.locale import Language
 
 class TestStringMethods(unittest.TestCase):
 
@@ -18,6 +19,11 @@ class TestStringMethods(unittest.TestCase):
         self.assertEqual(Role.Dark_Templar.get_role_type(), RoleType.Support)
         self.assertEqual(Role.Brakk.get_role_type(), RoleType.Hunter)
         self.assertEqual(Role.from_index(5), Role.Ares)
+        self.assertEqual(Role.Brakk.get_team(), Team.Kerrigan)
+        self.assertEqual(Role.Team_Nova.get_english_name(), Role.Team_Nova.get_name(Language.English))
+        self.assertEqual(Role["Scientist"], Role.from_index(1))
+        self.assertEqual(Role.Scientist, Role.from_index(1))
+
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
